'use strict';
import {mapActions} from "vuex";

function stringToNumber(str) {
  let result = 0;
  let len = str.length;
  for (let i = 0; i < len; i++) {
    result = result + str.charCodeAt(i) + i;
  }
  return result;
}

//==商城======
function checkV1(url){
  let reg = /^(https:\/\/jfb-public-images\.oss-cn-qingdao\.aliyuncs\.com).+$/;
  return reg.test(url)
}

function getV1Path(url) {
  let reg = /^(https:\/\/jfb-public-images\.oss-cn-qingdao\.aliyuncs\.com)/;
  url = url.replace(reg, '');
  //有参数配置去掉参数配置
  if(url.indexOf('?') !== -1) {
    url = url.split('?')[0]
  }
  return url;
}
//==商城======

//==蛋糕======
function checkCake(url) {
  let reg = /^(https:\/\/jfbcake\.oss-cn-beijing\.aliyuncs\.com).+$/;
  return reg.test(url);
}

function getCakePath(url) {
  let reg = /^(https:\/\/jfbcake\.oss-cn-beijing\.aliyuncs\.com)/;
  url = url.replace(reg, '');
  //有参数配置去掉参数配置
  if (url.indexOf('?') !== -1) {
    url = url.split('?')[0]
  }
  return url;
}
//==蛋糕======

/**
 * @description 获取图片访问地址
 * @param url {String} 图片路径
 * @param $vm {Vue} Vue实力
 * @param size {string} 取值：ize1 - size8
 */
export function getImageFullPath(url, $vm , size = 'size8') {

  if (Object.prototype.toString.call(url) !== '[object String]'
    || url === ''
  ) {
    console.error('传入的路径（path）非字符串类型，请确认路径是否正确');
    //throw new Error('传入的路径（path）非字符串类型，请确认路径是否正确');
  }

  //测试机地址替换
  let sandboxCdnReg = /(https:\/\/sandbox-img-jufubao-cn.oss-cn-qingdao.aliyuncs.com)/
  if(sandboxCdnReg.test(url)) {
    url = url.replace(sandboxCdnReg, '');
  }

  //兼容老图片地址访问
  let v1 = false;
  if(checkV1(url)) {
    v1 = true;
    url = getV1Path(url)
  }

  //兼容蛋糕图片访问地址
  let cake = false;
  if (checkCake(url)) {
    cake = true;
    url = getCakePath(url)
  }

  let baseUrl = $vm.$setting.cdnBaseUrl;

  //兼容老图片地址访问(只处理线上)
  if(v1) baseUrl = 'https://img@index@-v1.jufubao.cn'
  if(cake) baseUrl = 'https://cake-img@index@-v1.jufubao.cn'

  //带网络链接不处理
  let reg = /^(\/\/|http|https).+$/;
  if(reg.test(url)) return url;

  let index = stringToNumber(url) % 6;
  let doMain = baseUrl.replace('@index@', index === 0 ? '' : index);

  //图片压缩
  let sizeStyle = ''
  if (size) {
    sizeStyle = `?x-oss-process=style/${size}`
  }
  if (!/^(\/).+$/.test(url)) url = `/${url}`;
  return `${doMain}${url}${sizeStyle}`
}

export default {
  methods: {
    ...mapActions('oss', [
      'getOssSign'
    ]),

    /**
     * @description 获取富文本上传配置
     * @returns {{}}
     */
    getImageConfig(){
      return {
        sort: true,
        maxlen: 100,
        action: 'aliyun',
        qiniuCdn: 'aliyun',
        size: 5,
        tipsformet: '上传文件格式：@imageType@，不超过@size@MB.',
        uploadType: 'aliyun',
        type: ['jpg', 'png', 'jpeg', 'gif']
      }
    },

    /**启动上传图片*******=======================================*/
    /**
     * @description 上传到本地服务器成功返回值时刻触发，设置url字段
     */
    handleApiSuccessUrl(result, resolve) {
      resolve(result.data['ObjectURL'])
    },

    /**
     * @description 上传参数设置
     * @param file
     * @param resolve
     */
    handleGetParamsAndHeader(file, resolve) {

      // resolve({
      //   params: {
      //     token: genUpToken({
      //       accoutKey: 'bP3Ca5dtSJBNaWwMkihfhuE30CbAZnYrNzQm6eMN',
      //       serviceKey: 'pPNgWwRL3_Jlj7cPtpYbkhXn01EOZTtUhOs3NqZM',
      //       webSiteName: 'e56buystatic',
      //       staticUrl: 'http://static.e56buy.com',
      //     }),
      //     key: 'Xd' + this.$xdHelper.randomChar(30)
      //   }
      // });

      /**需要自己实现接口**/
      this.getOssSign({name: file.name})
        .then((res) => {
          let OSSAccessKeyId = res.data['id'];
          let cdnUrl = res.data['cdn_url']
          delete res.data['id'];
          delete res.data['cdn_url'];
          resolve({
            params: {
              ...res.data,
              OSSAccessKeyId: OSSAccessKeyId,
              name: file.name,
              cdnUrl: cdnUrl,
              success_action_status: 200
            }
          })
        })
        .catch(this.$xdLog.catch)
    },

    /**
     * @description 上传到私有桶参数设置
     * @param file
     * @param resolve
     */
    handlePrivateGetParamsAndHeader(file, resolve) {
      /**需要自己实现接口**/
      this.getOssSign({name: file.name, type: 'private'})
        .then((res) => {
          let OSSAccessKeyId = res.data['id']
          let cdnUrl = res.data['cdn_url']
          delete res.data['id']
          delete res.data['cdn_url']
          resolve({
            params: {
              ...res.data,
              OSSAccessKeyId: OSSAccessKeyId,
              name: file.name,
              cdnUrl: cdnUrl,
              success_action_status: 200
            }
          })
        })
        .catch(this.$xdLog.catch)
    },

    handleSuccess(res) {
      console.log('handleSuccess', res, this)
    },

    /**启动上传图片*******=======================================*/
    getImageFullPath(url,size){
      return getImageFullPath(url, this, size);
    },

  }
}

