'use strict';
module.exports = {
  name: "tradeRecord",
  title: "对账中心",
  vuex: true,
  model: [
    {
      title: "加盟商账户明细统计",
      mapFn: "countPartner",
      path: "/finance-partner/v1/trade-record/count-partner",
      isRule: false,
      params: {
        partner_id: ["加盟商ID", "string", "必填"],
        wallet_type: ["账户类型", "string", "必填"],
        operate_type: ["资金方向", "A:应付； R:应收", "必填"],
        trade_type: ["交易类型", "string", "必填"],
        main_order_id: ["主订单ID", "string", "非必填"],
        business_code: ["业务编码", "string", "非必填"],
        supplier_name: ["供应商名称", "string", "非必填"],
        start_time: ["开始时间", "string", "非必填"],
        end_time: ["结束时间", "string", "非必填"],
        page_size: ["每页条数", "number", "非必填"],
        page_token: ["翻页标识", "string", "非必填"],
      },
      disabled: true,
      "role": "FINANCE-PARTNER.TRADE_RECORD_COUNT_PARTNER"
    },
    {
      title: "供货商(渠道)账户明细统计",
      mapFn: "countSupplier",
      path: "/finance-partner/v1/trade-record/count-supplier",
      isRule: false,
      params: {
        supplier_id: ["供货商ID", "string", "必填"],
        wallet_type: ["账户类型", "string", "必填"],
        channel_code: ["渠道编码", "string", "必填"],
        operate_type: ["资金方向", "A:应付； R:应收", "必填"],
        trade_type: ["交易类型", "string", "必填"],
        main_order_id: ["主订单ID", "string", "非必填"],
        business_code: ["业务编码", "string", "非必填"],
        start_time: ["开始时间", "string", "非必填"],
        end_time: ["结束时间", "string", "非必填"],
        page_size: ["每页条数", "number", "非必填"],
        page_token: ["翻页标识", "string", "非必填"],
      },
      disabled: true,
      "role": "FINANCE-PARTNER.TRADE_RECORD_COUNT_SUPPLIER"
    },
    {
      title: "openApi账户明细统计",
      mapFn: "countOpenApi",
      path: "/finance-partner/v1/trade-record/count-open-api",
      isRule: false,
      params: {
        open_user_id: ["open api 用户ID", "string", "必填"],
        wallet_type: ["账户类型", "string", "必填"],
        operate_type: ["资金方向", "A:应付； R:应收", "必填"],
        trade_type: ["交易类型", "string", "必填"],
        main_order_id: ["主订单ID", "string", "非必填"],
        business_code: ["业务编码", "string", "非必填"],
        start_time: ["开始时间", "string", "非必填"],
        end_time: ["结束时间", "string", "非必填"],
        page_size: ["每页条数", "number", "非必填"],
        page_token: ["翻页标识", "string", "非必填"],
      },
      disabled: true,
      "role": "FINANCE-PARTNER.RECORD_COUNT_OPENAPI"
    },
    {
      title: "加盟商账户明细列表",
      mapFn: "listPartner",
      path: "/finance-partner/v1/trade-record/list-partner",
      isRule: false,
      params: {
        partner_id: ["加盟商ID", "string", "必填"],
        wallet_type: ["账户类型", "string", "必填"],
        operate_type: ["资金方向", "A:应付； R:应收", "必填"],
        trade_type: ["交易类型", "string", "必填"],
        main_order_id: ["主订单ID", "string", "非必填"],
        business_code: ["业务编码", "string", "非必填"],
        supplier_name: ["供应商名称", "string", "非必填"],
        start_time: ["开始时间", "string", "非必填"],
        end_time: ["结束时间", "string", "非必填"],
        page_size: ["每页条数", "number", "非必填"],
        page_token: ["翻页标识", "string", "非必填"],
      },
      disabled: true,
      "role": "FINANCE-PARTNER.TRADE_RECORD_LIST_PARTNER"
    },
    {
      title: "供货商(渠道)账户明细列表",
      mapFn: "listSupplier",
      path: "/finance-partner/v1/trade-record/list-supplier",
      isRule: false,
      params: {
        supplier_id: ["供货商ID", "string", "必填"],
        wallet_type: ["账户类型", "string", "必填"],
        channel_code: ["渠道编码", "string", "必填"],
        operate_type: ["资金方向", "A:应付； R:应收", "必填"],
        trade_type: ["交易类型", "string", "必填"],
        main_order_id: ["主订单ID", "string", "非必填"],
        business_code: ["业务编码", "string", "非必填"],
        start_time: ["开始时间", "string", "非必填"],
        end_time: ["结束时间", "string", "非必填"],
        page_size: ["每页条数", "number", "非必填"],
        page_token: ["翻页标识", "string", "非必填"],
      },
      disabled: true,
      "role": "FINANCE-PARTNER.TRADE_RECORD_LIST_SUPPLIER"
    },
    {
      title: "openApi账户明细列表",
      mapFn: "listOpenApi",
      path: "/finance-partner/v1/trade-record/list-open-api",
      isRule: false,
      params: {
        open_user_id: ["open api 用户ID", "string", "必填"],
        wallet_type: ["账户类型", "string", "必填"],
        operate_type: ["资金方向", "A:应付； R:应收", "必填"],
        trade_type: ["交易类型", "string", "必填"],
        main_order_id: ["主订单ID", "string", "非必填"],
        business_code: ["业务编码", "string", "非必填"],
        start_time: ["开始时间", "string", "非必填"],
        end_time: ["结束时间", "string", "非必填"],
        page_size: ["每页条数", "number", "非必填"],
        page_token: ["翻页标识", "string", "非必填"],
      },
      disabled: true,
      "role": "FINANCE-PARTNER.RECORD_LIST_OPENAPI"
    },
    {
      title: "加盟商明细-页面参数",
      mapFn: "getChannelList",
      path: "/finance-partner/v1/trade-record/list-partner-options",
      isRule: false,
      params: {},
      disabled: true,
      "role": "FINANCE-PARTNER.WALLET_LIST_PARTNER_OPTIONS"
    },
    {
      title: "加盟商明细-渠道下供货商列表",
      mapFn: "getSupplierList",
      path: "/finance-partner/v1/trade-record/list-channel-suppliers",
      isRule: false,
      params: {
        value: ["渠道编号", "", "必填"],
        keyword: ["搜索", "", "必填"],
      },
      disabled: true,
      "role": "FINANCE-PARTNER.WALLET_LIST_PARTNER_CHANNEL_SUPPLIERS"
    }
  ]
} 